==> CoGAPS_3.2.1.tar.gz: CoGAPS/src/GapsResult.cpp <==
#include "GapsResult.h"

#include "GapsStatistics.h"
#include "file_parser/FileParser.h"

template <class T>
static std::string to_string(T a)
{
    std::stringstream ss;
    ss << a;
    return ss.str();
}

GapsResult::GapsResult(const GapsStatistics &stat)
    :
Amean(stat.Amean()), Asd(stat.Asd()), Pmean(stat.Pmean()),
Psd(stat.Psd()), meanChiSq(0.f), seed(0)
{}

void GapsResult::writeToFile(const std::string &fullPath)
{
    std::size_t pos = fullPath.find_last_of('.');
    std::string base = fullPath.substr(0, pos);

    switch (FileParser::fileType(fullPath))
    {
        case GAPS_CSV: return writeCsv(base);
        case GAPS_TSV: return writeTsv(base);
        case GAPS_GCT: return writeGct(base);
        default : GAPS_ERROR("Invalid File Type");
    }
}

void GapsResult::writeCsv(const std::string &path)
{
    unsigned nPatterns = Amean.nCol();
    std::string label("_" + to_string(nPatterns) + "_");
    FileParser::writeToCsv(path + label + "Amean.csv", Amean);
    FileParser::writeToCsv(path + label + "Pmean.csv", Pmean);
    FileParser::writeToCsv(path + label + "Asd.csv", Asd);
    FileParser::writeToCsv(path + label + "Psd.csv", Psd);
}

void GapsResult::writeTsv(const std::string &path)
{
    unsigned nPatterns = Amean.nCol();
    std::string label("_" + to_string(nPatterns) + "_");
    FileParser::writeToCsv(path + label + "Amean.tsv", Amean);
    FileParser::writeToCsv(path + label + "Pmean.tsv", Pmean);
    FileParser::writeToCsv(path + label + "Asd.tsv", Asd);
    FileParser::writeToCsv(path + label + "Psd.tsv", Psd);
}

void GapsResult::writeGct(const std::string &path)
{
    unsigned nPatterns = Amean.nCol();
    std::string label("_" + to_string(nPatterns) + "_");
    FileParser::writeToCsv(path + label + "Amean.gct", Amean);
    FileParser::writeToCsv(path + label + "Pmean.gct", Pmean);
    FileParser::writeToCsv(path + label + "Asd.gct", Asd);
    FileParser::writeToCsv(path + label + "Psd.gct", Psd);
}

==> CoGAPS_3.2.40.tar.gz: CoGAPS/src/GapsResult.cpp <==
#include "GapsResult.h"

#include "GapsStatistics.h"
#include "file_parser/FileParser.h"

template <class T>
static std::string to_string(T a)
{
    std::stringstream ss;
    ss << a;
    return ss.str();
}

GapsResult::GapsResult(const GapsStatistics &stat)
    :
Amean(stat.Amean()), Asd(stat.Asd()), Pmean(stat.Pmean()),
Psd(stat.Psd()), meanChiSq(0.f), seed(0), chisqHistory(stat.chisqHistory()),
atomHistoryA(stat.atomHistory('A')), atomHistoryP(stat.atomHistory('P'))
{}

void GapsResult::writeToFile(const std::string &fullPath)
{
    std::size_t pos = fullPath.find_last_of('.');
    std::string base = fullPath.substr(0, pos);

    switch (FileParser::fileType(fullPath))
    {
        case GAPS_CSV: return writeCsv(base);
        case GAPS_TSV: return writeTsv(base);
        case GAPS_GCT: return writeGct(base);
        default : GAPS_ERROR("Invalid File Type");
    }
}

void GapsResult::writeCsv(const std::string &path)
{
    unsigned nPatterns = Amean.nCol();
    std::string label("_" + to_string(nPatterns) + "_");
    FileParser::writeToCsv(path + label + "Amean.csv", Amean);
    FileParser::writeToCsv(path + label + "Pmean.csv", Pmean);
    FileParser::writeToCsv(path + label + "Asd.csv", Asd);
    FileParser::writeToCsv(path + label + "Psd.csv", Psd);
}

void GapsResult::writeTsv(const std::string &path)
{
    unsigned nPatterns = Amean.nCol();
    std::string label("_" + to_string(nPatterns) + "_");
    FileParser::writeToCsv(path + label + "Amean.tsv", Amean);
    FileParser::writeToCsv(path + label + "Pmean.tsv", Pmean);
    FileParser::writeToCsv(path + label + "Asd.tsv", Asd);
    FileParser::writeToCsv(path + label + "Psd.tsv", Psd);
}

void GapsResult::writeGct(const std::string &path)
{
    unsigned nPatterns = Amean.nCol();
    std::string label("_" + to_string(nPatterns) + "_");
    FileParser::writeToCsv(path + label + "Amean.gct", Amean);
    FileParser::writeToCsv(path + label + "Pmean.gct", Pmean);
    FileParser::writeToCsv(path + label + "Asd.gct", Asd);
    FileParser::writeToCsv(path + label + "Psd.gct", Psd);
}
